(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[390],{16972:(e,a,o)=>{Promise.resolve().then(o.bind(o,83578))},83578:(e,a,o)=>{"use strict";o.r(a),o.d(a,{default:()=>p});var s=o(23892),i=o(85848),t=o(57182),n=o(42522),r=o(16844),m=o(88431);let d=[{prompt_image:"https://cdn.smoosense.ai/datasets/image-to-video-human-preference-hailuo-02-marey/Images/63.jpg",prompt:"The camera gently circles the blooming rose, capturing its petals in soft focus.",video1:"https://cdn.smoosense.ai/datasets/image-to-video-human-preference-hailuo-02-marey/Videos/marey/marey_0063.mp4",video2:"https://cdn.smoosense.ai/datasets/image-to-video-human-preference-hailuo-02-marey/Videos/hailuo-02/hailuo-02_camera-motion_0063.mp4",video1_preference:.144156351685524},{prompt_image:"https://cdn.smoosense.ai/datasets/image-to-video-human-preference-hailuo-02-marey/Images/92.jpg",prompt:"The camera slowly zooms in on the unfurling plant, capturing its vibrant colors and intricate details.",video1:"https://cdn.smoosense.ai/datasets/image-to-video-human-preference-hailuo-02-marey/Videos/marey/marey_0092.mp4",video2:"https://cdn.smoosense.ai/datasets/image-to-video-human-preference-hailuo-02-marey/Videos/hailuo-02/hailuo-02_camera-motion_0092.mp4",video1_preference:.12658114731311798},{prompt_image:"https://cdn.smoosense.ai/datasets/image-to-video-human-preference-hailuo-02-marey/Images/20.jpg",prompt:"Birds soar gracefully across the glowing sunset sky as gentle wind rustles the lone tree's branches.",video1:"https://cdn.smoosense.ai/datasets/image-to-video-human-preference-hailuo-02-marey/Videos/marey/marey_0020.mp4",video2:"https://cdn.smoosense.ai/datasets/image-to-video-human-preference-hailuo-02-marey/Videos/hailuo-02/hailuo-02_scene-motion_0020.mp4",video1_preference:.22711089253425598},{prompt_image:"https://cdn.smoosense.ai/datasets/image-to-video-human-preference-hailuo-02-marey/Images/68.jpg",prompt:"The subject paddles smoothly across the misty lake, creating gentle ripples in the water.",video1:"https://cdn.smoosense.ai/datasets/image-to-video-human-preference-hailuo-02-marey/Videos/marey/marey_0068.mp4",video2:"https://cdn.smoosense.ai/datasets/image-to-video-human-preference-hailuo-02-marey/Videos/hailuo-02/hailuo-02_subject-motion_0068.mp4",video1_preference:.18394294381141663}];function l(e){let{className:a}=e,o=(0,i.useMemo)(()=>({prompt_image:{headerName:"Reference Image",width:250,pinned:"left"},prompt:{headerName:"Prompt",width:200,flex:1},video1:{headerName:"Model 1 Video",width:250},video2:{headerName:"Model 2 Video",width:250}}),[]);return(0,s.jsx)("div",{className:"h-full w-full ".concat(a||""),children:(0,s.jsxs)(n.N,{direction:"horizontal",defaultSizes:[70,30],minSize:50,maxSize:80,children:[(0,s.jsxs)("div",{className:"h-full flex flex-col",children:[(0,s.jsx)("div",{className:"w-full flex items-center justify-center p-3",children:(0,s.jsx)(m.A,{settingKey:"autoPlayAllVideos",label:"Auto Play All Videos"})}),(0,s.jsx)("div",{className:"flex-1",children:(0,s.jsx)(t.A,{data:d,colDefOverrides:o,gridOptionOverrides:{rowHeight:150}})})]}),(0,s.jsx)("div",{className:"h-full p-6 bg-background border-l overflow-y-auto",children:(0,s.jsx)(r.A,{children:"# Text-to-Video Comparison\n\nSmooSense provides a platform to evaluate and compare different text-to-video AI models. \nBy presenting videos generated from the same prompt side-by-side, it allows for a direct visual assessment of each model's quality and performance.\n\nThis example shows how to analyze and compare video generation results from multiple models using the same prompts and reference images.\n\n## Data Source\n\nData is excerpted from:\n[Rapidata/image-to-video-human-preference-hailuo-02-marey](https://huggingface.co/datasets/Rapidata/image-to-video-human-preference-hailuo-02-marey)\n\n---\n\n## Use SmooSense to compare videos\n- Hover at a video to play.\n- Click the switch to turn on/off auto-play for all videos.\n\n"})})]})})}var c=o(76652);function p(){return(0,i.useEffect)(()=>{document.title="Text-to-Video Comparison Example - SmooSense"},[]),(0,s.jsxs)("div",{className:"min-h-screen bg-background",children:[(0,s.jsx)(c.A,{iconButtons:[]}),(0,s.jsx)("main",{className:"h-[calc(100vh-56px)] p-4",children:(0,s.jsx)("div",{className:"h-full",children:(0,s.jsx)(l,{})})})]})}}},e=>{e.O(0,[265,652,346,933,504,484,577,496,213,947,29,542,358],()=>e(e.s=16972)),_N_E=e.O()}]);